@@ -191,6 +191,7 @@ eog_preferences_dialog_constructor (GType type,
 	EogPreferencesDialogPrivate *priv;
 	GtkWidget *dlg;
 	GtkWidget *interpolate_check;
+	GtkWidget *extrapolate_check;
 	GtkWidget *autorotate_check;
 	GtkWidget *color_radio;
 	GtkWidget *checkpattern_radio;
@@ -201,6 +202,8 @@ eog_preferences_dialog_constructor (GType type,
 	GtkWidget *seconds_spin;
 	GtkWidget *plugin_manager;
 	GtkWidget *plugin_manager_container;
+	GtkWidget *netbook_mode_check;
+	GtkWidget *xdgpic_fallback_check;
 	GObject *object;
 	GdkColor color;
 	gchar *value;
@@ -217,6 +220,7 @@ eog_preferences_dialog_constructor (GType type,
 	eog_dialog_get_controls (EOG_DIALOG (object),
 			         "eog_preferences_dialog", &dlg,
 			         "interpolate_check", &interpolate_check,
+			         "extrapolate_check", &extrapolate_check,
 			         "autorotate_check", &autorotate_check,
 			         "color_radio", &color_radio,
 			         "checkpattern_radio", &checkpattern_radio,
@@ -226,6 +230,8 @@ eog_preferences_dialog_constructor (GType type,
 			         "loop_check", &loop_check,
 			         "seconds_spin", &seconds_spin,
 			         "plugin_manager_container", &plugin_manager_container,
+			         "netbook_mode_check", &netbook_mode_check,
+			         "xdgpic_fallback_check", &xdgpic_fallback_check,
 			         NULL);
 
 	g_signal_connect (G_OBJECT (dlg),
@@ -238,15 +244,29 @@ eog_preferences_dialog_constructor (GType type,
 							     EOG_CONF_VIEW_INTERPOLATE,
 							     NULL));
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (extrapolate_check),
+				      gconf_client_get_bool (priv->client,
+							     EOG_CONF_VIEW_EXTRAPOLATE,
+							     NULL));
+
 	g_object_set_data (G_OBJECT (interpolate_check),
 			   GCONF_OBJECT_KEY,
 			   EOG_CONF_VIEW_INTERPOLATE);
 
+	g_object_set_data (G_OBJECT (extrapolate_check),
+			   GCONF_OBJECT_KEY,
+			   EOG_CONF_VIEW_EXTRAPOLATE);
+
 	g_signal_connect (G_OBJECT (interpolate_check),
 			  "toggled",
 			  G_CALLBACK (pd_check_toggle_cb),
 			  priv->client);
 
+	g_signal_connect (G_OBJECT (extrapolate_check),
+			  "toggled",
+			  G_CALLBACK (pd_check_toggle_cb),
+			  priv->client);
+
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (autorotate_check),
 				      gconf_client_get_bool (priv->client,
 							     EOG_CONF_VIEW_AUTOROTATE,
@@ -390,6 +410,35 @@ eog_preferences_dialog_constructor (GType type,
 
         gtk_widget_show_all (plugin_manager);
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (netbook_mode_check),
+				      gconf_client_get_bool (priv->client,
+							     EOG_CONF_UI_PROPSDIALOG_NETBOOK_MODE,
+							     NULL));
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (xdgpic_fallback_check),
+				      gconf_client_get_bool (priv->client,
+							     EOG_CONF_UI_FILECHOOSER_XDG_FALLBACK,
+							     NULL));
+
+	g_object_set_data (G_OBJECT (netbook_mode_check),
+			   GCONF_OBJECT_KEY,
+			   EOG_CONF_UI_PROPSDIALOG_NETBOOK_MODE);
+
+	g_object_set_data (G_OBJECT (xdgpic_fallback_check),
+			   GCONF_OBJECT_KEY,
+			   EOG_CONF_UI_FILECHOOSER_XDG_FALLBACK);
+
+	g_signal_connect (G_OBJECT (netbook_mode_check),
+			  "toggled",
+			  G_CALLBACK (pd_check_toggle_cb),
+			  priv->client);
+
+	g_signal_connect (G_OBJECT (xdgpic_fallback_check),
+			  "toggled",
+			  G_CALLBACK (pd_check_toggle_cb),
+			  priv->client);
+
+
 	return object;
 }
 
